==> haskell-cairo-0.13.12.0-16-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   cairo
version:                0.13.12.0
visibility:             public
id:                     cairo-0.13.12.0-EK2nm68HmFdAWU4se40pHT
key:                    cairo-0.13.12.0-EK2nm68HmFdAWU4se40pHT
license:                BSD-3-Clause
copyright:
    (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:               Graphics
abi:                    6e0a994a8a3f83f1db71b053835457fa
exposed:                True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types

hidden-modules:
    Graphics.Rendering.Cairo.Internal.Drawing.Cairo
    Graphics.Rendering.Cairo.Internal.Drawing.Paths
    Graphics.Rendering.Cairo.Internal.Drawing.Patterns
    Graphics.Rendering.Cairo.Internal.Drawing.Text
    Graphics.Rendering.Cairo.Internal.Drawing.Transformations
    Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
    Graphics.Rendering.Cairo.Internal.Surfaces.Image
    Graphics.Rendering.Cairo.Internal.Surfaces.PNG
    Graphics.Rendering.Cairo.Internal.Surfaces.Surface
    Graphics.Rendering.Cairo.Internal.Utilities
    Graphics.Rendering.Cairo.Internal.Surfaces.PDF
    Graphics.Rendering.Cairo.Internal.Surfaces.PS
    Graphics.Rendering.Cairo.Internal.Surfaces.SVG
    Graphics.Rendering.Cairo.Internal.Region

import-dirs:            /usr/lib/ghc-9.4.8/site-local/cairo-0.13.12.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/cairo-0.13.12.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/cairo-0.13.12.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-cairo
hs-libraries:           HScairo-0.13.12.0-EK2nm68HmFdAWU4se40pHT
extra-libraries:        cairo png16 z
extra-libraries-static:
    cairo m dl fontconfig m expat m freetype dl bz2 brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m png16 m m z

include-dirs:
    /usr/include/cairo /usr/include/freetype2 /usr/include/pixman-1
    /usr/include/libpng16

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 mtl-2.2.2
    text-2.0.2 utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:     /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html:           /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cairo-0.13.12.0-21-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-cairo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   cairo
version:                0.13.12.0
visibility:             public
id:                     cairo-0.13.12.0-WsRl5c30Pb1liJZ4gKqMu
key:                    cairo-0.13.12.0-WsRl5c30Pb1liJZ4gKqMu
license:                BSD-3-Clause
copyright:
    (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004

maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Axel Simon, Duncan Coutts
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to the Cairo library.
description:
    Cairo is a library to render high quality vector graphics. There
    exist various backends that allows rendering to Gtk windows, PDF,
    PS, PNG and SVG documents, amongst others.

category:               Graphics
abi:                    dfc07eea13b30835731eb88cf71cb210
exposed:                True
exposed-modules:
    Graphics.Rendering.Cairo Graphics.Rendering.Cairo.Internal
    Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types

hidden-modules:
    Graphics.Rendering.Cairo.Internal.Drawing.Cairo
    Graphics.Rendering.Cairo.Internal.Drawing.Paths
    Graphics.Rendering.Cairo.Internal.Drawing.Patterns
    Graphics.Rendering.Cairo.Internal.Drawing.Text
    Graphics.Rendering.Cairo.Internal.Drawing.Transformations
    Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
    Graphics.Rendering.Cairo.Internal.Surfaces.Image
    Graphics.Rendering.Cairo.Internal.Surfaces.PNG
    Graphics.Rendering.Cairo.Internal.Surfaces.Surface
    Graphics.Rendering.Cairo.Internal.Utilities
    Graphics.Rendering.Cairo.Internal.Surfaces.PDF
    Graphics.Rendering.Cairo.Internal.Surfaces.PS
    Graphics.Rendering.Cairo.Internal.Surfaces.SVG
    Graphics.Rendering.Cairo.Internal.Region

import-dirs:            /usr/lib/ghc-9.6.7.20250817/site-local/cairo-0.13.12.0
library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/cairo-0.13.12.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/cairo-0.13.12.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-cairo
hs-libraries:           HScairo-0.13.12.0-WsRl5c30Pb1liJZ4gKqMu
extra-libraries:        cairo png16 z
extra-libraries-static:
    cairo m dl fontconfig m expat m freetype dl bz2 brotlidec
    brotlicommon Xext Xrender X11 pthread xcb-render xcb-shm xcb Xau
    Xdmcp pixman-1 m png16 m m z

include-dirs:
    /usr/include /usr/include/cairo /usr/include/freetype2
    /usr/include/pixman-1 /usr/include/libpng16

depends:
    array-0.5.8.0 base-4.18.3.0 bytestring-0.11.5.4 mtl-2.3.1
    text-2.0.2 utf8-string-1.0.2-shiuprzUpU7bW4pJ3bW0

haddock-interfaces:     /usr/share/doc/haskell-cairo/html/cairo.haddock
haddock-html:           /usr/share/doc/haskell-cairo/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
